# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.trace_download_result import TraceDownloadResult

class TestTraceDownloadResult(unittest.TestCase):
    """TraceDownloadResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TraceDownloadResult:
        """Test TraceDownloadResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TraceDownloadResult`
        """
        model = TraceDownloadResult()
        if include_optional:
            return TraceDownloadResult(
                adjusted_timeframe = instana_client.models.adjusted_timeframe.AdjustedTimeframe(
                    to = 56, 
                    window_size = 0, ),
                can_load_more = True,
                items = [
                    instana_client.models.get_trace_download_result_item.GetTraceDownloadResultItem(
                        call_count = 56, 
                        cursor = instana_client.models.cursor.cursor(), 
                        destination = instana_client.models.call_relation.CallRelation(
                            endpoint = instana_client.models.endpoint_simple.EndpointSimple(
                                id = '', 
                                label = '', 
                                type = 'UNDEFINED', ), 
                            service = instana_client.models.service_simple.ServiceSimple(
                                id = '', 
                                label = '', ), 
                            technologies = [
                                ''
                                ], ), 
                        duration = 56, 
                        error_count = 56, 
                        foreign_parent_id = '', 
                        id = '', 
                        min_self_time = 56, 
                        name = '', 
                        network_time = 56, 
                        parent_id = '', 
                        timestamp = 56, )
                    ],
                total_hits = 0,
                total_represented_item_count = 0,
                total_retained_item_count = 0
            )
        else:
            return TraceDownloadResult(
                items = [
                    instana_client.models.get_trace_download_result_item.GetTraceDownloadResultItem(
                        call_count = 56, 
                        cursor = instana_client.models.cursor.cursor(), 
                        destination = instana_client.models.call_relation.CallRelation(
                            endpoint = instana_client.models.endpoint_simple.EndpointSimple(
                                id = '', 
                                label = '', 
                                type = 'UNDEFINED', ), 
                            service = instana_client.models.service_simple.ServiceSimple(
                                id = '', 
                                label = '', ), 
                            technologies = [
                                ''
                                ], ), 
                        duration = 56, 
                        error_count = 56, 
                        foreign_parent_id = '', 
                        id = '', 
                        min_self_time = 56, 
                        name = '', 
                        network_time = 56, 
                        parent_id = '', 
                        timestamp = 56, )
                    ],
        )
        """

    def testTraceDownloadResult(self):
        """Test TraceDownloadResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBytes, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from instana_client.models.test_result_subtransaction import TestResultSubtransaction
from typing import Optional, Set
from typing_extensions import Self

class TestResultDetailData(BaseModel):
    """
    TestResultDetailData
    """ # noqa: E501
    har: Optional[Dict[str, Dict[str, Any]]] = None
    image_files: Optional[Dict[str, List[Union[StrictBytes, StrictStr]]]] = Field(default=None, alias="imageFiles")
    log_files: Optional[Dict[str, StrictStr]] = Field(default=None, alias="logFiles")
    logs: Optional[StrictStr] = None
    subtransaction_avg_metrics: Optional[Dict[str, Dict[str, Any]]] = Field(default=None, alias="subtransactionAvgMetrics")
    subtransactions: Optional[List[TestResultSubtransaction]] = None
    test_id: Optional[StrictStr] = Field(default=None, alias="testId")
    test_result_id: Optional[StrictStr] = Field(default=None, alias="testResultId")
    videos: Optional[List[Union[StrictBytes, StrictStr]]] = None
    __properties: ClassVar[List[str]] = ["har", "imageFiles", "logFiles", "logs", "subtransactionAvgMetrics", "subtransactions", "testId", "testResultId", "videos"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TestResultDetailData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in subtransactions (list)
        _items = []
        if self.subtransactions:
            for _item_subtransactions in self.subtransactions:
                if _item_subtransactions:
                    _items.append(_item_subtransactions.to_dict())
            _dict['subtransactions'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TestResultDetailData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "har": obj.get("har"),
            "imageFiles": obj.get("imageFiles"),
            "logFiles": obj.get("logFiles"),
            "logs": obj.get("logs"),
            "subtransactionAvgMetrics": obj.get("subtransactionAvgMetrics"),
            "subtransactions": [TestResultSubtransaction.from_dict(_item) for _item in obj["subtransactions"]] if obj.get("subtransactions") is not None else None,
            "testId": obj.get("testId"),
            "testResultId": obj.get("testResultId"),
            "videos": obj.get("videos")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.maintenance_configuration_api import MaintenanceConfigurationApi


class TestMaintenanceConfigurationApi(unittest.TestCase):
    """MaintenanceConfigurationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MaintenanceConfigurationApi()

    def tearDown(self) -> None:
        pass

    def test_delete_maintenance_config(self) -> None:
        """Test case for delete_maintenance_config

        Delete maintenance configuration
        """
        pass

    def test_delete_maintenance_config_v2(self) -> None:
        """Test case for delete_maintenance_config_v2

        Delete maintenance configuration
        """
        pass

    def test_get_maintenance_config(self) -> None:
        """Test case for get_maintenance_config

        Maintenance configuration
        """
        pass

    def test_get_maintenance_config_v2(self) -> None:
        """Test case for get_maintenance_config_v2

        Get maintenance configuration
        """
        pass

    def test_get_maintenance_configs(self) -> None:
        """Test case for get_maintenance_configs

        All maintenance configurations
        """
        pass

    def test_get_maintenance_configs_v2(self) -> None:
        """Test case for get_maintenance_configs_v2

        All maintenance configurations
        """
        pass

    def test_pause_recurrent_maintenance_configuration(self) -> None:
        """Test case for pause_recurrent_maintenance_configuration

        Pause maintenance configuration
        """
        pass

    def test_put_maintenance_config(self) -> None:
        """Test case for put_maintenance_config

        Create or update maintenance configuration
        """
        pass

    def test_put_maintenance_config_v2(self) -> None:
        """Test case for put_maintenance_config_v2

        Create or update maintenance configuration
        """
        pass

    def test_resume_recurrent_maintenance_configuration(self) -> None:
        """Test case for resume_recurrent_maintenance_configuration

        Resume maintenance configuration
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr, field_validator
from typing import Optional
from typing_extensions import Annotated
from instana_client.models.service_map import ServiceMap

from instana_client.api_client import ApiClient, RequestSerialized
from instana_client.api_response import ApiResponse
from instana_client.rest import RESTResponseType


class ApplicationTopologyApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_services_map(
        self,
        window_size: Annotated[Optional[StrictInt], Field(description="Size of time window in milliseconds")] = None,
        to: Annotated[Optional[StrictInt], Field(description="Timestamp since Unix Epoch in milliseconds of the end of the time window")] = None,
        application_id: Annotated[Optional[StrictStr], Field(description="Filter by application ID")] = None,
        application_boundary_scope: Annotated[Optional[StrictStr], Field(description="Filter by application scope, i.e., INBOUND or ALL. The default value is INBOUND. Applies only if application ID filter is specified.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ServiceMap:
        """Gets the service topology

        Use this API endpoint if one wants to retrieve services and connections (call paths) between them for calls in the scope given by the parameters.  ## Errata:  The following fields are unsupported but documented in the schema for the result `services`: - The `applications` field is always missing and the `snapshotIds` field is always empty, despite being declared as required in the result schema. - The `maxSeverity` and `numberOfOpenIssues` fields are always missing. 

        :param window_size: Size of time window in milliseconds
        :type window_size: int
        :param to: Timestamp since Unix Epoch in milliseconds of the end of the time window
        :type to: int
        :param application_id: Filter by application ID
        :type application_id: str
        :param application_boundary_scope: Filter by application scope, i.e., INBOUND or ALL. The default value is INBOUND. Applies only if application ID filter is specified.
        :type application_boundary_scope: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_services_map_serialize(
            window_size=window_size,
            to=to,
            application_id=application_id,
            application_boundary_scope=application_boundary_scope,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ServiceMap",
            '400': None,
            '401': None,
            '403': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_services_map_with_http_info(
        self,
        window_size: Annotated[Optional[StrictInt], Field(description="Size of time window in milliseconds")] = None,
        to: Annotated[Optional[StrictInt], Field(description="Timestamp since Unix Epoch in milliseconds of the end of the time window")] = None,
        application_id: Annotated[Optional[StrictStr], Field(description="Filter by application ID")] = None,
        application_boundary_scope: Annotated[Optional[StrictStr], Field(description="Filter by application scope, i.e., INBOUND or ALL. The default value is INBOUND. Applies only if application ID filter is specified.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ServiceMap]:
        """Gets the service topology

        Use this API endpoint if one wants to retrieve services and connections (call paths) between them for calls in the scope given by the parameters.  ## Errata:  The following fields are unsupported but documented in the schema for the result `services`: - The `applications` field is always missing and the `snapshotIds` field is always empty, despite being declared as required in the result schema. - The `maxSeverity` and `numberOfOpenIssues` fields are always missing. 

        :param window_size: Size of time window in milliseconds
        :type window_size: int
        :param to: Timestamp since Unix Epoch in milliseconds of the end of the time window
        :type to: int
        :param application_id: Filter by application ID
        :type application_id: str
        :param application_boundary_scope: Filter by application scope, i.e., INBOUND or ALL. The default value is INBOUND. Applies only if application ID filter is specified.
        :type application_boundary_scope: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_services_map_serialize(
            window_size=window_size,
            to=to,
            application_id=application_id,
            application_boundary_scope=application_boundary_scope,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ServiceMap",
            '400': None,
            '401': None,
            '403': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_services_map_without_preload_content(
        self,
        window_size: Annotated[Optional[StrictInt], Field(description="Size of time window in milliseconds")] = None,
        to: Annotated[Optional[StrictInt], Field(description="Timestamp since Unix Epoch in milliseconds of the end of the time window")] = None,
        application_id: Annotated[Optional[StrictStr], Field(description="Filter by application ID")] = None,
        application_boundary_scope: Annotated[Optional[StrictStr], Field(description="Filter by application scope, i.e., INBOUND or ALL. The default value is INBOUND. Applies only if application ID filter is specified.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Gets the service topology

        Use this API endpoint if one wants to retrieve services and connections (call paths) between them for calls in the scope given by the parameters.  ## Errata:  The following fields are unsupported but documented in the schema for the result `services`: - The `applications` field is always missing and the `snapshotIds` field is always empty, despite being declared as required in the result schema. - The `maxSeverity` and `numberOfOpenIssues` fields are always missing. 

        :param window_size: Size of time window in milliseconds
        :type window_size: int
        :param to: Timestamp since Unix Epoch in milliseconds of the end of the time window
        :type to: int
        :param application_id: Filter by application ID
        :type application_id: str
        :param application_boundary_scope: Filter by application scope, i.e., INBOUND or ALL. The default value is INBOUND. Applies only if application ID filter is specified.
        :type application_boundary_scope: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_services_map_serialize(
            window_size=window_size,
            to=to,
            application_id=application_id,
            application_boundary_scope=application_boundary_scope,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ServiceMap",
            '400': None,
            '401': None,
            '403': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_services_map_serialize(
        self,
        window_size,
        to,
        application_id,
        application_boundary_scope,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if window_size is not None:
            
            _query_params.append(('windowSize', window_size))
            
        if to is not None:
            
            _query_params.append(('to', to))
            
        if application_id is not None:
            
            _query_params.append(('applicationId', application_id))
            
        if application_boundary_scope is not None:
            
            _query_params.append(('applicationBoundaryScope', application_boundary_scope))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/application-monitoring/topology/services',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.infrastructure_resources_api import InfrastructureResourcesApi


class TestInfrastructureResourcesApi(unittest.TestCase):
    """InfrastructureResourcesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = InfrastructureResourcesApi()

    def tearDown(self) -> None:
        pass

    def test_get_monitoring_state(self) -> None:
        """Test case for get_monitoring_state

        Monitored host count
        """
        pass

    def test_get_plugin_payload(self) -> None:
        """Test case for get_plugin_payload

        Get a payload for a snapshot
        """
        pass

    def test_get_snapshot(self) -> None:
        """Test case for get_snapshot

        Get snapshot details
        """
        pass

    def test_get_snapshots(self) -> None:
        """Test case for get_snapshots

        Search snapshots
        """
        pass

    def test_post_snapshots(self) -> None:
        """Test case for post_snapshots

        Get snapshot details for multiple snapshots
        """
        pass

    def test_software_versions(self) -> None:
        """Test case for software_versions

        Get installed software
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.synthetic_calls_api import SyntheticCallsApi


class TestSyntheticCallsApi(unittest.TestCase):
    """SyntheticCallsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SyntheticCallsApi()

    def tearDown(self) -> None:
        pass

    def test_delete_synthetic_call(self) -> None:
        """Test case for delete_synthetic_call

        Delete synthetic call configurations
        """
        pass

    def test_get_synthetic_calls(self) -> None:
        """Test case for get_synthetic_calls

        Synthetic call configurations
        """
        pass

    def test_update_synthetic_call(self) -> None:
        """Test case for update_synthetic_call

        Update synthetic call configurations
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict
from typing import Any, ClassVar, Dict, List, Optional
from instana_client.models.cloudfoundry_physical_context import CloudfoundryPhysicalContext
from instana_client.models.kubernetes_physical_context import KubernetesPhysicalContext
from instana_client.models.snapshot_preview import SnapshotPreview
from typing import Optional, Set
from typing_extensions import Self

class PhysicalContext(BaseModel):
    """
    The physical context of an entity. This is typically used to describe where a host, container or process fits into the infrastructure. 1. `cloudfoundry`: Contains physical context of Cloudfoundry. 2. `cluster`: Contains physical context of cluster like Hazelcast, Elasticsearch. 3. `container`: Contains physical context of container. 4. `host`: Contains physical context of host. 5. `kubernetes`: Contains physical context of Kubernetes. 6. `process`: Contains physical context of a process. 
    """ # noqa: E501
    cloudfoundry: Optional[CloudfoundryPhysicalContext] = None
    cluster: Optional[SnapshotPreview] = None
    container: Optional[SnapshotPreview] = None
    host: Optional[SnapshotPreview] = None
    kubernetes: Optional[KubernetesPhysicalContext] = None
    process: Optional[SnapshotPreview] = None
    __properties: ClassVar[List[str]] = ["cloudfoundry", "cluster", "container", "host", "kubernetes", "process"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PhysicalContext from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of cloudfoundry
        if self.cloudfoundry:
            _dict['cloudfoundry'] = self.cloudfoundry.to_dict()
        # override the default output from pydantic by calling `to_dict()` of cluster
        if self.cluster:
            _dict['cluster'] = self.cluster.to_dict()
        # override the default output from pydantic by calling `to_dict()` of container
        if self.container:
            _dict['container'] = self.container.to_dict()
        # override the default output from pydantic by calling `to_dict()` of host
        if self.host:
            _dict['host'] = self.host.to_dict()
        # override the default output from pydantic by calling `to_dict()` of kubernetes
        if self.kubernetes:
            _dict['kubernetes'] = self.kubernetes.to_dict()
        # override the default output from pydantic by calling `to_dict()` of process
        if self.process:
            _dict['process'] = self.process.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PhysicalContext from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "cloudfoundry": CloudfoundryPhysicalContext.from_dict(obj["cloudfoundry"]) if obj.get("cloudfoundry") is not None else None,
            "cluster": SnapshotPreview.from_dict(obj["cluster"]) if obj.get("cluster") is not None else None,
            "container": SnapshotPreview.from_dict(obj["container"]) if obj.get("container") is not None else None,
            "host": SnapshotPreview.from_dict(obj["host"]) if obj.get("host") is not None else None,
            "kubernetes": KubernetesPhysicalContext.from_dict(obj["kubernetes"]) if obj.get("kubernetes") is not None else None,
            "process": SnapshotPreview.from_dict(obj["process"]) if obj.get("process") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.business_monitoring_api import BusinessMonitoringApi


class TestBusinessMonitoringApi(unittest.TestCase):
    """BusinessMonitoringApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BusinessMonitoringApi()

    def tearDown(self) -> None:
        pass

    def test_create_business_perspective(self) -> None:
        """Test case for create_business_perspective

        Create business perspective
        """
        pass

    def test_delete_business_perspective(self) -> None:
        """Test case for delete_business_perspective

        Delete business perspective
        """
        pass

    def test_get_activities(self) -> None:
        """Test case for get_activities

        Get Business Activities
        """
        pass

    def test_get_activities_csv(self) -> None:
        """Test case for get_activities_csv

        Download Business Activities
        """
        pass

    def test_get_business_perspective(self) -> None:
        """Test case for get_business_perspective

        Get business perspective
        """
        pass

    def test_get_business_perspectives(self) -> None:
        """Test case for get_business_perspectives

        Get all business perspectives
        """
        pass

    def test_get_business_tag_catalog(self) -> None:
        """Test case for get_business_tag_catalog

        Get business tag catalog
        """
        pass

    def test_update_business_perspective(self) -> None:
        """Test case for update_business_perspective

        Update business perspective
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.application_config import ApplicationConfig

class TestApplicationConfig(unittest.TestCase):
    """ApplicationConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApplicationConfig:
        """Test ApplicationConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApplicationConfig`
        """
        model = ApplicationConfig()
        if include_optional:
            return ApplicationConfig(
                access_rules = [
                    instana_client.models.access_rule.AccessRule(
                        access_type = 'READ', 
                        related_id = '', 
                        relation_type = 'USER', )
                    ],
                boundary_scope = 'ALL',
                id = '0',
                label = '0',
                match_specification = instana_client.models.match_expression_dto.MatchExpressionDTO(
                    type = '', ),
                scope = 'INCLUDE_NO_DOWNSTREAM',
                tag_filter_expression = instana_client.models.tag_filter_expression_element.TagFilterExpressionElement(
                    type = '', )
            )
        else:
            return ApplicationConfig(
                access_rules = [
                    instana_client.models.access_rule.AccessRule(
                        access_type = 'READ', 
                        related_id = '', 
                        relation_type = 'USER', )
                    ],
                boundary_scope = 'ALL',
                id = '0',
                label = '0',
                scope = 'INCLUDE_NO_DOWNSTREAM',
        )
        """

    def testApplicationConfig(self):
        """Test ApplicationConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class LLMEgressGateway(BaseModel):
    """
    Custom handler definition.
    """ # noqa: E501
    ai_model: Optional[StrictStr] = Field(default=None, alias="aiModel")
    configurations: Optional[Dict[str, Any]] = None
    created_at: StrictStr = Field(alias="createdAt")
    description: Optional[StrictStr] = None
    enabled: Optional[StrictBool] = None
    endpoint_api_key: Optional[StrictStr] = Field(default=None, alias="endpointApiKey")
    endpoint_url: Optional[StrictStr] = Field(default=None, alias="endpointUrl")
    id: StrictStr
    instana_agents: Optional[Dict[str, Any]] = Field(default=None, alias="instanaAgents")
    metadata: Optional[Dict[str, Any]] = None
    modified_at: StrictStr = Field(alias="modifiedAt")
    name: StrictStr
    prompt: StrictStr
    supports: Dict[str, Any]
    system: Optional[StrictBool] = None
    tenant_unit_id: StrictStr = Field(alias="tenantUnitId")
    watsonx_key: Optional[StrictStr] = Field(default=None, alias="watsonxKey")
    watsonx_project: Optional[StrictStr] = Field(default=None, alias="watsonxProject")
    watsonx_url: Optional[StrictStr] = Field(default=None, alias="watsonxUrl")
    __properties: ClassVar[List[str]] = ["aiModel", "configurations", "createdAt", "description", "enabled", "endpointApiKey", "endpointUrl", "id", "instanaAgents", "metadata", "modifiedAt", "name", "prompt", "supports", "system", "tenantUnitId", "watsonxKey", "watsonxProject", "watsonxUrl"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of LLMEgressGateway from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of LLMEgressGateway from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "aiModel": obj.get("aiModel"),
            "configurations": obj.get("configurations"),
            "createdAt": obj.get("createdAt"),
            "description": obj.get("description"),
            "enabled": obj.get("enabled"),
            "endpointApiKey": obj.get("endpointApiKey"),
            "endpointUrl": obj.get("endpointUrl"),
            "id": obj.get("id"),
            "instanaAgents": obj.get("instanaAgents"),
            "metadata": obj.get("metadata"),
            "modifiedAt": obj.get("modifiedAt"),
            "name": obj.get("name"),
            "prompt": obj.get("prompt"),
            "supports": obj.get("supports"),
            "system": obj.get("system"),
            "tenantUnitId": obj.get("tenantUnitId"),
            "watsonxKey": obj.get("watsonxKey"),
            "watsonxProject": obj.get("watsonxProject"),
            "watsonxUrl": obj.get("watsonxUrl")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.action_instance import ActionInstance

class TestActionInstance(unittest.TestCase):
    """ActionInstance unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ActionInstance:
        """Test ActionInstance
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ActionInstance`
        """
        model = ActionInstance()
        if include_optional:
            return ActionInstance(
                action_description = '',
                action_id = '',
                action_instance_id = '',
                action_name = '',
                action_snapshot = '',
                actor_id = '',
                actor_name = '',
                actor_type = 'ACTOR_UNKNOWN',
                created_date = 56,
                end_date = 56,
                error_message = '',
                event_entity_type = '',
                event_id = '',
                event_specification_id = '',
                external_source_type = '',
                host_snapshot_id = '',
                input_parameters = [
                    instana_client.models.action_instance_parameter.ActionInstanceParameter(
                        display_name = '', 
                        name = '', 
                        type = '', 
                        value = '', )
                    ],
                metadata = [
                    instana_client.models.action_instance_metadata_entry.ActionInstanceMetadataEntry(
                        name = '', 
                        value = '', )
                    ],
                output = '',
                policy_id = '',
                problem_text = '',
                return_code = 56,
                start_date = 56,
                status = 'STATUS_UNKNOWN',
                target_snapshot_id = '',
                type = 'SCRIPT'
            )
        else:
            return ActionInstance(
                action_id = '',
                action_name = '',
                type = 'SCRIPT',
        )
        """

    def testActionInstance(self):
        """Test ActionInstance"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.groups_api import GroupsApi


class TestGroupsApi(unittest.TestCase):
    """GroupsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = GroupsApi()

    def tearDown(self) -> None:
        pass

    def test_add_permissions_on_group(self) -> None:
        """Test case for add_permissions_on_group

        Add permissions to group
        """
        pass

    def test_add_users_to_group(self) -> None:
        """Test case for add_users_to_group

        Add users to group
        """
        pass

    def test_create_group(self) -> None:
        """Test case for create_group

        Create group
        """
        pass

    def test_create_group_mapping(self) -> None:
        """Test case for create_group_mapping

        Create group mapping
        """
        pass

    def test_delete_group(self) -> None:
        """Test case for delete_group

        Delete group
        """
        pass

    def test_delete_group_mapping(self) -> None:
        """Test case for delete_group_mapping

        Delete group mapping
        """
        pass

    def test_delete_group_mappings(self) -> None:
        """Test case for delete_group_mappings

        Delete multiple group mappings
        """
        pass

    def test_delete_groups(self) -> None:
        """Test case for delete_groups

        Delete groups
        """
        pass

    def test_get_group(self) -> None:
        """Test case for get_group

        Get group
        """
        pass

    def test_get_group_mapping(self) -> None:
        """Test case for get_group_mapping

        Get group mapping
        """
        pass

    def test_get_group_mappings(self) -> None:
        """Test case for get_group_mappings

        Get all group mappings
        """
        pass

    def test_get_group_mappings_overview(self) -> None:
        """Test case for get_group_mappings_overview

        Get all group mappings overview
        """
        pass

    def test_get_groups(self) -> None:
        """Test case for get_groups

        Get groups
        """
        pass

    def test_get_groups_by_user(self) -> None:
        """Test case for get_groups_by_user

        Get groups of a single user
        """
        pass

    def test_get_identity_provider_patch(self) -> None:
        """Test case for get_identity_provider_patch

        Check user restrictions for empty Idp group mapping
        """
        pass

    def test_remove_user_from_group(self) -> None:
        """Test case for remove_user_from_group

        Remove user from group
        """
        pass

    def test_update_group(self) -> None:
        """Test case for update_group

        Update group
        """
        pass

    def test_update_group_mapping(self) -> None:
        """Test case for update_group_mapping

        Update group mapping
        """
        pass

    def test_update_identity_provider(self) -> None:
        """Test case for update_identity_provider

        Allow/Restrict users with empty Idp group mapping
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from instana_client.models.trigger import Trigger
from instana_client.models.type_configuration import TypeConfiguration
from typing import Optional, Set
from typing_extensions import Self

class Policy(BaseModel):
    """
    Policy
    """ # noqa: E501
    description: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=512)]] = Field(default=None, description="Policy description.")
    id: Annotated[str, Field(min_length=1, strict=True, max_length=128)] = Field(description="Policy identifier.")
    name: Annotated[str, Field(min_length=1, strict=True, max_length=128)] = Field(description="Policy name.")
    tags: Optional[List[StrictStr]] = Field(default=None, description="A list of policy tags.")
    trigger: Trigger
    type_configurations: List[TypeConfiguration] = Field(description="List of configurations that contains the list of actions to run and the mode (automatic or manual) in which the policy is run.", alias="typeConfigurations")
    __properties: ClassVar[List[str]] = ["description", "id", "name", "tags", "trigger", "typeConfigurations"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Policy from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "id",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of trigger
        if self.trigger:
            _dict['trigger'] = self.trigger.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in type_configurations (list)
        _items = []
        if self.type_configurations:
            for _item_type_configurations in self.type_configurations:
                if _item_type_configurations:
                    _items.append(_item_type_configurations.to_dict())
            _dict['typeConfigurations'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Policy from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "description": obj.get("description"),
            "id": obj.get("id"),
            "name": obj.get("name"),
            "tags": obj.get("tags"),
            "trigger": Trigger.from_dict(obj["trigger"]) if obj.get("trigger") is not None else None,
            "typeConfigurations": [TypeConfiguration.from_dict(_item) for _item in obj["typeConfigurations"]] if obj.get("typeConfigurations") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.custom_entity_model import CustomEntityModel

class TestCustomEntityModel(unittest.TestCase):
    """CustomEntityModel unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CustomEntityModel:
        """Test CustomEntityModel
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CustomEntityModel`
        """
        model = CustomEntityModel()
        if include_optional:
            return CustomEntityModel(
                dashboards = [
                    instana_client.models.custom_dashboard.CustomDashboard(
                        access_rules = [
                            instana_client.models.access_rule.AccessRule(
                                access_type = 'READ', 
                                related_id = '', 
                                relation_type = 'USER', )
                            ], 
                        id = '', 
                        title = '', 
                        widgets = [
                            instana_client.models.widget.Widget(
                                config = instana_client.models.config.config(), 
                                height = 1, 
                                id = '', 
                                title = '', 
                                type = '', 
                                width = 1, 
                                x = 0, 
                                y = 0, )
                            ], )
                    ],
                dependencies = [
                    instana_client.models.custom_dependency.CustomDependency(
                        direction = 'outgoing', 
                        entity_type = '', 
                        identifiers = [
                            ''
                            ], 
                        name = '', 
                        type = 'in', )
                    ],
                identifiers = [
                    ''
                    ],
                label = '',
                metrics = [
                    instana_client.models.custom_metric.CustomMetric(
                        aggregation = 'AVG', 
                        category = '', 
                        description = '', 
                        formatter = 'NUMBER', 
                        label = '', 
                        name = '', 
                        section = 'ACE', 
                        source = '', 
                        type = '', )
                    ],
                tag_filter_expression = instana_client.models.tag_filter_expression_element.TagFilterExpressionElement(
                    type = '', )
            )
        else:
            return CustomEntityModel(
                identifiers = [
                    ''
                    ],
                label = '',
                tag_filter_expression = instana_client.models.tag_filter_expression_element.TagFilterExpressionElement(
                    type = '', ),
        )
        """

    def testCustomEntityModel(self):
        """Test CustomEntityModel"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.action_match import ActionMatch

class TestActionMatch(unittest.TestCase):
    """ActionMatch unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ActionMatch:
        """Test ActionMatch
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ActionMatch`
        """
        model = ActionMatch()
        if include_optional:
            return ActionMatch(
                action = instana_client.models.action.Action(
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    description = '', 
                    fields = [
                        instana_client.models.field.Field(
                            description = '', 
                            encoding = '', 
                            name = '', 
                            secured = True, 
                            value = '', )
                        ], 
                    id = '0', 
                    input_parameters = [
                        instana_client.models.parameter.Parameter(
                            description = '', 
                            hidden = True, 
                            label = '', 
                            name = '', 
                            required = True, 
                            secured = True, 
                            type = '', 
                            value = '', )
                        ], 
                    metadata = instana_client.models.meta_data.MetaData(
                        ai = [
                            {
                                'key' : None
                                }
                            ], 
                        ai_originated = True, 
                        built_in = True, 
                        read_only = True, 
                        sensor_imported = True, ), 
                    modified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    name = '0', 
                    tags = [
                        ''
                        ], 
                    type = 'SCRIPT', ),
                ai_engine = 'POLICY',
                confidence = '',
                policy = instana_client.models.policy.Policy(
                    description = '', 
                    id = '0', 
                    name = '0', 
                    tags = [
                        ''
                        ], 
                    trigger = instana_client.models.trigger.Trigger(
                        description = '', 
                        id = '', 
                        name = '', 
                        scheduling = instana_client.models.policy_scheduling.PolicyScheduling(
                            recurrent_rule = '', 
                            start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        type = 'customEvent', ), 
                    type_configurations = [
                        instana_client.models.type_configuration.TypeConfiguration(
                            condition = instana_client.models.condition.Condition(
                                query = '', ), 
                            name = 'automatic', 
                            runnable = instana_client.models.policy_runnable.PolicyRunnable(
                                id = '', 
                                run_configuration = instana_client.models.run_configuration.RunConfiguration(
                                    actions = [
                                        instana_client.models.action_configuration.ActionConfiguration(
                                            action = instana_client.models.action.Action(
                                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                description = '', 
                                                fields = [
                                                    instana_client.models.field.Field(
                                                        description = '', 
                                                        encoding = '', 
                                                        name = '', 
                                                        secured = True, 
                                                        value = '', )
                                                    ], 
                                                id = '0', 
                                                input_parameters = [
                                                    instana_client.models.parameter.Parameter(
                                                        description = '', 
                                                        hidden = True, 
                                                        label = '', 
                                                        name = '', 
                                                        required = True, 
                                                        secured = True, 
                                                        type = '', 
                                                        value = '', )
                                                    ], 
                                                metadata = instana_client.models.meta_data.MetaData(
                                                    ai = [
                                                        {
                                                            'key' : None
                                                            }
                                                        ], 
                                                    ai_originated = True, 
                                                    built_in = True, 
                                                    read_only = True, 
                                                    sensor_imported = True, ), 
                                                modified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                                name = '0', 
                                                type = 'SCRIPT', ), 
                                            agent_id = '', 
                                            input_parameter_values = [
                                                instana_client.models.parameter_value.ParameterValue(
                                                    name = '', 
                                                    value = '', )
                                                ], )
                                        ], ), 
                                type = 'action', ), )
                        ], ),
                score = 1.337
            )
        else:
            return ActionMatch(
                ai_engine = 'POLICY',
                confidence = '',
                score = 1.337,
        )
        """

    def testActionMatch(self):
        """Test ActionMatch"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.simple_metric_configuration import SimpleMetricConfiguration

class TestSimpleMetricConfiguration(unittest.TestCase):
    """SimpleMetricConfiguration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SimpleMetricConfiguration:
        """Test SimpleMetricConfiguration
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SimpleMetricConfiguration`
        """
        model = SimpleMetricConfiguration()
        if include_optional:
            return SimpleMetricConfiguration(
                aggregation = 'SUM',
                cross_series_aggregation = 'SUM',
                granularity = 56,
                metric = '',
                regex = True,
                required = True,
                operation = instana_client.models.arithmetic_operation.ArithmeticOperation(
                    left = instana_client.models.arithmetic_operand.ArithmeticOperand(), 
                    operator = '', 
                    right = instana_client.models.arithmetic_operand.ArithmeticOperand(), )
            )
        else:
            return SimpleMetricConfiguration(
                aggregation = 'SUM',
                metric = '',
        )
        """

    def testSimpleMetricConfiguration(self):
        """Test SimpleMetricConfiguration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from importlib import import_module
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from instana_client.models.tag_filter_expression_element import TagFilterExpressionElement
from typing import Optional, Set
from typing_extensions import Self

from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from instana_client.models.application_apdex_entity import ApplicationApdexEntity
    from instana_client.models.website_apdex_entity import WebsiteApdexEntity

class ApdexEntity(BaseModel):
    """
    Entity which holds the information of Apdex Configuration
    """ # noqa: E501
    apdex_type: StrictStr = Field(alias="apdexType")
    entity_id: StrictStr = Field(alias="entityId")
    tag_filter_expression: TagFilterExpressionElement = Field(alias="tagFilterExpression")
    threshold: Optional[Annotated[int, Field(strict=True, ge=1)]] = None
    __properties: ClassVar[List[str]] = ["apdexType", "entityId", "tagFilterExpression", "threshold"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    # JSON field name that stores the object type
    __discriminator_property_name: ClassVar[str] = 'apdexType'

    # discriminator mappings
    __discriminator_value_class_map: ClassVar[Dict[str, str]] = {
        'application': 'ApplicationApdexEntity','website': 'WebsiteApdexEntity'
    }

    @classmethod
    def get_discriminator_value(cls, obj: Dict[str, Any]) -> Optional[str]:
        """Returns the discriminator value (object type) of the data"""
        discriminator_value = obj[cls.__discriminator_property_name]
        if discriminator_value:
            return cls.__discriminator_value_class_map.get(discriminator_value)
        else:
            return None

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Union[ApplicationApdexEntity, WebsiteApdexEntity]]:
        """Create an instance of ApdexEntity from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of tag_filter_expression
        if self.tag_filter_expression:
            _dict['tagFilterExpression'] = self.tag_filter_expression.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict[str, Any]) -> Optional[Union[ApplicationApdexEntity, WebsiteApdexEntity]]:
        """Create an instance of ApdexEntity from a dict"""
        # look up the object type based on discriminator mapping
        object_type = cls.get_discriminator_value(obj)
        if object_type ==  'ApplicationApdexEntity':
            return import_module("instana_client.models.application_apdex_entity").ApplicationApdexEntity.from_dict(obj)
        if object_type ==  'WebsiteApdexEntity':
            return import_module("instana_client.models.website_apdex_entity").WebsiteApdexEntity.from_dict(obj)

        raise ValueError("ApdexEntity failed to lookup discriminator value from " +
                            json.dumps(obj) + ". Discriminator property name: " + cls.__discriminator_property_name +
                            ", mapping: " + json.dumps(cls.__discriminator_value_class_map))





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.test_result import TestResult

class TestTestResult(unittest.TestCase):
    """TestResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TestResult:
        """Test TestResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TestResult`
        """
        model = TestResult()
        if include_optional:
            return TestResult(
                test_result = [
                    instana_client.models.test_result_item.TestResultItem(
                        application_id = '', 
                        application_ids = [
                            ''
                            ], 
                        custom_tags = {
                            'key' : ''
                            }, 
                        location_id = [
                            ''
                            ], 
                        metrics = [
                            {
                                'key' : None
                                }
                            ], 
                        mobile_application_ids = [
                            ''
                            ], 
                        service_id = '', 
                        test_id = '', 
                        test_name = '', 
                        website_ids = [
                            ''
                            ], )
                    ],
                test_result_items = [
                    instana_client.models.test_result_item.TestResultItem(
                        application_id = '', 
                        application_ids = [
                            ''
                            ], 
                        custom_tags = {
                            'key' : ''
                            }, 
                        location_id = [
                            ''
                            ], 
                        metrics = [
                            {
                                'key' : None
                                }
                            ], 
                        mobile_application_ids = [
                            ''
                            ], 
                        service_id = '', 
                        test_id = '', 
                        test_name = '', 
                        website_ids = [
                            ''
                            ], )
                    ]
            )
        else:
            return TestResult(
        )
        """

    def testTestResult(self):
        """Test TestResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from instana_client.models.js_stack_trace_line import JsStackTraceLine
from typing import Optional, Set
from typing_extensions import Self

class WebsiteMonitoringBeacon(BaseModel):
    """
    WebsiteMonitoringBeacon
    """ # noqa: E501
    accuracy_radius: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="accuracyRadius")
    accurate_timings_available: Optional[StrictBool] = Field(default=None, alias="accurateTimingsAvailable")
    agent_version: Optional[StrictStr] = Field(default=None, alias="agentVersion")
    app_cache_time: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="appCacheTime")
    backend_time: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="backendTime")
    backend_trace_id: Optional[StrictStr] = Field(default=None, alias="backendTraceId")
    batch_size: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=None, alias="batchSize")
    beacon_id: StrictStr = Field(alias="beaconId")
    browser_name: Optional[StrictStr] = Field(default=None, alias="browserName")
    browser_version: Optional[StrictStr] = Field(default=None, alias="browserVersion")
    bytes_ingested: Optional[StrictInt] = Field(default=None, alias="bytesIngested")
    cache_interaction: Optional[StrictStr] = Field(default=None, alias="cacheInteraction")
    children_time: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="childrenTime")
    city: Optional[StrictStr] = None
    clock_skew: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="clockSkew")
    component_stack: Optional[StrictStr] = Field(default=None, alias="componentStack")
    connection_type: Optional[StrictStr] = Field(default=None, alias="connectionType")
    continent: Optional[StrictStr] = None
    continent_code: Optional[StrictStr] = Field(default=None, alias="continentCode")
    country: Optional[StrictStr] = None
    country_code: Optional[StrictStr] = Field(default=None, alias="countryCode")
    csp_blocked_uri: Optional[StrictStr] = Field(default=None, alias="cspBlockedUri")
    csp_column_number: Optional[StrictInt] = Field(default=None, alias="cspColumnNumber")
    csp_disposition: Optional[StrictStr] = Field(default=None, alias="cspDisposition")
    csp_effective_directive: Optional[StrictStr] = Field(default=None, alias="cspEffectiveDirective")
    csp_line_number: Optional[StrictInt] = Field(default=None, alias="cspLineNumber")
    csp_original_policy: Optional[StrictStr] = Field(default=None, alias="cspOriginalPolicy")
    csp_sample: Optional[StrictStr] = Field(default=None, alias="cspSample")
    csp_source_file: Optional[StrictStr] = Field(default=None, alias="cspSourceFile")
    cumulative_layout_shift: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="cumulativeLayoutShift")
    custom_event_name: Optional[StrictStr] = Field(default=None, alias="customEventName")
    custom_metric: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="customMetric")
    decoded_body_size: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="decodedBodySize")
    deprecations: Optional[Annotated[List[StrictStr], Field(min_length=0, max_length=16)]] = None
    device_type: Optional[StrictStr] = Field(default=None, alias="deviceType")
    dns_time: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="dnsTime")
    dom_time: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="domTime")
    duration: Optional[Annotated[int, Field(strict=True, ge=0)]] = None
    encoded_body_size: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="encodedBodySize")
    error_count: Optional[Annotated[int, Field(strict=True, ge=0)]] = Field(default=None, alias="errorCount")
    error_id: Optional[StrictStr] = Field(default=None, alias="errorId")
    error_message: Optional[StrictStr] = Field(default=None, alias="errorMessage")
    error_type: Optional[StrictStr] = Field(default=None, alias="errorType")
    first_contentful_paint_time: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="firstContentfulPaintTime")
    first_input_delay_time: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="firstInputDelayTime")
    first_paint_time: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="firstPaintTime")
    frontend_time: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="frontendTime")
    graphql_operation_name: Optional[StrictStr] = Field(default=None, alias="graphqlOperationName")
    graphql_operation_type: Optional[StrictStr] = Field(default=None, alias="graphqlOperationType")
    http_call_asynchronous: Optional[StrictBool] = Field(default=None, alias="httpCallAsynchronous")
    http_call_correlation_attempted: Optional[StrictBool] = Field(default=None, alias="httpCallCorrelationAttempted")
    http_call_headers: Optional[Dict[str, StrictStr]] = Field(default=None, alias="httpCallHeaders")
    http_call_method: Optional[StrictStr] = Field(default=None, alias="httpCallMethod")
    http_call_origin: Optional[StrictStr] = Field(default=None, alias="httpCallOrigin")
    http_call_path: Optional[StrictStr] = Field(default=None, alias="httpCallPath")
    http_call_status: Optional[Annotated[int, Field(le=599, strict=True, ge=-1)]] = Field(default=None, alias="httpCallStatus")
    http_call_url: Optional[StrictStr] = Field(default=None, alias="httpCallUrl")
    initiator: Optional[StrictStr] = None
    interaction_next_paint: Optional[StrictInt] = Field(default=None, alias="interactionNextPaint")
    internal_meta: Optional[Dict[str, StrictStr]] = Field(default=None, alias="internalMeta")
    label: Optional[StrictStr] = None
    largest_contentful_paint_time: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="largestContentfulPaintTime")
    latitude: Optional[Union[StrictFloat, StrictInt]] = None
    location_origin: StrictStr = Field(alias="locationOrigin")
    location_path: Optional[StrictStr] = Field(default=None, alias="locationPath")
    location_url: StrictStr = Field(alias="locationUrl")
    longitude: Optional[Union[StrictFloat, StrictInt]] = None
    meta: Optional[Dict[str, StrictStr]] = None
    on_load_time: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="onLoadTime")
    os_name: Optional[StrictStr] = Field(default=None, alias="osName")
    os_version: Optional[StrictStr] = Field(default=None, alias="osVersion")
    page: Optional[StrictStr] = None
    page_load_id: StrictStr = Field(alias="pageLoadId")
    parent_beacon_id: Optional[StrictStr] = Field(default=None, alias="parentBeaconId")
    parsed_stack_trace: Optional[Annotated[List[JsStackTraceLine], Field(min_length=0, max_length=64)]] = Field(default=None, alias="parsedStackTrace")
    phase: Optional[StrictStr] = None
    processing_time: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="processingTime")
    redirect_time: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="redirectTime")
    request_time: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="requestTime")
    resource_type: Optional[StrictStr] = Field(default=None, alias="resourceType")
    response_time: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="responseTime")
    session_id: Optional[StrictStr] = Field(default=None, alias="sessionId")
    snippet_version: Optional[StrictStr] = Field(default=None, alias="snippetVersion")
    ssl_time: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="sslTime")
    stack_trace: Optional[StrictStr] = Field(default=None, alias="stackTrace")
    stack_trace_parsing_status: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="stackTraceParsingStatus")
    stack_trace_readability: Optional[Annotated[int, Field(strict=True, ge=0)]] = Field(default=None, alias="stackTraceReadability")
    subdivision: Optional[StrictStr] = None
    subdivision_code: Optional[StrictStr] = Field(default=None, alias="subdivisionCode")
    tcp_time: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="tcpTime")
    timestamp: Optional[Annotated[int, Field(strict=True, ge=1)]] = None
    transfer_size: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="transferSize")
    type: StrictStr
    unload_time: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="unloadTime")
    use_features: Optional[Annotated[List[StrictStr], Field(min_length=0, max_length=15)]] = Field(default=None, alias="useFeatures")
    user_email: Optional[StrictStr] = Field(default=None, alias="userEmail")
    user_id: Optional[StrictStr] = Field(default=None, alias="userId")
    user_ip: Optional[StrictStr] = Field(default=None, alias="userIp")
    user_languages: Optional[Annotated[List[StrictStr], Field(min_length=0, max_length=5)]] = Field(default=None, alias="userLanguages")
    user_name: Optional[StrictStr] = Field(default=None, alias="userName")
    website_id: StrictStr = Field(alias="websiteId")
    website_label: StrictStr = Field(alias="websiteLabel")
    window_height: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="windowHeight")
    window_hidden: Optional[StrictBool] = Field(default=None, alias="windowHidden")
    window_width: Optional[Annotated[int, Field(strict=True, ge=-1)]] = Field(default=None, alias="windowWidth")
    __properties: ClassVar[List[str]] = ["accuracyRadius", "accurateTimingsAvailable", "agentVersion", "appCacheTime", "backendTime", "backendTraceId", "batchSize", "beaconId", "browserName", "browserVersion", "bytesIngested", "cacheInteraction", "childrenTime", "city", "clockSkew", "componentStack", "connectionType", "continent", "continentCode", "country", "countryCode", "cspBlockedUri", "cspColumnNumber", "cspDisposition", "cspEffectiveDirective", "cspLineNumber", "cspOriginalPolicy", "cspSample", "cspSourceFile", "cumulativeLayoutShift", "customEventName", "customMetric", "decodedBodySize", "deprecations", "deviceType", "dnsTime", "domTime", "duration", "encodedBodySize", "errorCount", "errorId", "errorMessage", "errorType", "firstContentfulPaintTime", "firstInputDelayTime", "firstPaintTime", "frontendTime", "graphqlOperationName", "graphqlOperationType", "httpCallAsynchronous", "httpCallCorrelationAttempted", "httpCallHeaders", "httpCallMethod", "httpCallOrigin", "httpCallPath", "httpCallStatus", "httpCallUrl", "initiator", "interactionNextPaint", "internalMeta", "label", "largestContentfulPaintTime", "latitude", "locationOrigin", "locationPath", "locationUrl", "longitude", "meta", "onLoadTime", "osName", "osVersion", "page", "pageLoadId", "parentBeaconId", "parsedStackTrace", "phase", "processingTime", "redirectTime", "requestTime", "resourceType", "responseTime", "sessionId", "snippetVersion", "sslTime", "stackTrace", "stackTraceParsingStatus", "stackTraceReadability", "subdivision", "subdivisionCode", "tcpTime", "timestamp", "transferSize", "type", "unloadTime", "useFeatures", "userEmail", "userId", "userIp", "userLanguages", "userName", "websiteId", "websiteLabel", "windowHeight", "windowHidden", "windowWidth"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of WebsiteMonitoringBeacon from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in parsed_stack_trace (list)
        _items = []
        if self.parsed_stack_trace:
            for _item_parsed_stack_trace in self.parsed_stack_trace:
                if _item_parsed_stack_trace:
                    _items.append(_item_parsed_stack_trace.to_dict())
            _dict['parsedStackTrace'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of WebsiteMonitoringBeacon from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "accuracyRadius": obj.get("accuracyRadius"),
            "accurateTimingsAvailable": obj.get("accurateTimingsAvailable"),
            "agentVersion": obj.get("agentVersion"),
            "appCacheTime": obj.get("appCacheTime"),
            "backendTime": obj.get("backendTime"),
            "backendTraceId": obj.get("backendTraceId"),
            "batchSize": obj.get("batchSize"),
            "beaconId": obj.get("beaconId"),
            "browserName": obj.get("browserName"),
            "browserVersion": obj.get("browserVersion"),
            "bytesIngested": obj.get("bytesIngested"),
            "cacheInteraction": obj.get("cacheInteraction"),
            "childrenTime": obj.get("childrenTime"),
            "city": obj.get("city"),
            "clockSkew": obj.get("clockSkew"),
            "componentStack": obj.get("componentStack"),
            "connectionType": obj.get("connectionType"),
            "continent": obj.get("continent"),
            "continentCode": obj.get("continentCode"),
            "country": obj.get("country"),
            "countryCode": obj.get("countryCode"),
            "cspBlockedUri": obj.get("cspBlockedUri"),
            "cspColumnNumber": obj.get("cspColumnNumber"),
            "cspDisposition": obj.get("cspDisposition"),
            "cspEffectiveDirective": obj.get("cspEffectiveDirective"),
            "cspLineNumber": obj.get("cspLineNumber"),
            "cspOriginalPolicy": obj.get("cspOriginalPolicy"),
            "cspSample": obj.get("cspSample"),
            "cspSourceFile": obj.get("cspSourceFile"),
            "cumulativeLayoutShift": obj.get("cumulativeLayoutShift"),
            "customEventName": obj.get("customEventName"),
            "customMetric": obj.get("customMetric"),
            "decodedBodySize": obj.get("decodedBodySize"),
            "deprecations": obj.get("deprecations"),
            "deviceType": obj.get("deviceType"),
            "dnsTime": obj.get("dnsTime"),
            "domTime": obj.get("domTime"),
            "duration": obj.get("duration"),
            "encodedBodySize": obj.get("encodedBodySize"),
            "errorCount": obj.get("errorCount"),
            "errorId": obj.get("errorId"),
            "errorMessage": obj.get("errorMessage"),
            "errorType": obj.get("errorType"),
            "firstContentfulPaintTime": obj.get("firstContentfulPaintTime"),
            "firstInputDelayTime": obj.get("firstInputDelayTime"),
            "firstPaintTime": obj.get("firstPaintTime"),
            "frontendTime": obj.get("frontendTime"),
            "graphqlOperationName": obj.get("graphqlOperationName"),
            "graphqlOperationType": obj.get("graphqlOperationType"),
            "httpCallAsynchronous": obj.get("httpCallAsynchronous"),
            "httpCallCorrelationAttempted": obj.get("httpCallCorrelationAttempted"),
            "httpCallHeaders": obj.get("httpCallHeaders"),
            "httpCallMethod": obj.get("httpCallMethod"),
            "httpCallOrigin": obj.get("httpCallOrigin"),
            "httpCallPath": obj.get("httpCallPath"),
            "httpCallStatus": obj.get("httpCallStatus"),
            "httpCallUrl": obj.get("httpCallUrl"),
            "initiator": obj.get("initiator"),
            "interactionNextPaint": obj.get("interactionNextPaint"),
            "internalMeta": obj.get("internalMeta"),
            "label": obj.get("label"),
            "largestContentfulPaintTime": obj.get("largestContentfulPaintTime"),
            "latitude": obj.get("latitude"),
            "locationOrigin": obj.get("locationOrigin"),
            "locationPath": obj.get("locationPath"),
            "locationUrl": obj.get("locationUrl"),
            "longitude": obj.get("longitude"),
            "meta": obj.get("meta"),
            "onLoadTime": obj.get("onLoadTime"),
            "osName": obj.get("osName"),
            "osVersion": obj.get("osVersion"),
            "page": obj.get("page"),
            "pageLoadId": obj.get("pageLoadId"),
            "parentBeaconId": obj.get("parentBeaconId"),
            "parsedStackTrace": [JsStackTraceLine.from_dict(_item) for _item in obj["parsedStackTrace"]] if obj.get("parsedStackTrace") is not None else None,
            "phase": obj.get("phase"),
            "processingTime": obj.get("processingTime"),
            "redirectTime": obj.get("redirectTime"),
            "requestTime": obj.get("requestTime"),
            "resourceType": obj.get("resourceType"),
            "responseTime": obj.get("responseTime"),
            "sessionId": obj.get("sessionId"),
            "snippetVersion": obj.get("snippetVersion"),
            "sslTime": obj.get("sslTime"),
            "stackTrace": obj.get("stackTrace"),
            "stackTraceParsingStatus": obj.get("stackTraceParsingStatus"),
            "stackTraceReadability": obj.get("stackTraceReadability"),
            "subdivision": obj.get("subdivision"),
            "subdivisionCode": obj.get("subdivisionCode"),
            "tcpTime": obj.get("tcpTime"),
            "timestamp": obj.get("timestamp"),
            "transferSize": obj.get("transferSize"),
            "type": obj.get("type"),
            "unloadTime": obj.get("unloadTime"),
            "useFeatures": obj.get("useFeatures"),
            "userEmail": obj.get("userEmail"),
            "userId": obj.get("userId"),
            "userIp": obj.get("userIp"),
            "userLanguages": obj.get("userLanguages"),
            "userName": obj.get("userName"),
            "websiteId": obj.get("websiteId"),
            "websiteLabel": obj.get("websiteLabel"),
            "windowHeight": obj.get("windowHeight"),
            "windowHidden": obj.get("windowHidden"),
            "windowWidth": obj.get("windowWidth")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.application_analyze_api import ApplicationAnalyzeApi


class TestApplicationAnalyzeApi(unittest.TestCase):
    """ApplicationAnalyzeApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApplicationAnalyzeApi()

    def tearDown(self) -> None:
        pass

    def test_get_call_details(self) -> None:
        """Test case for get_call_details

        Get call detail
        """
        pass

    def test_get_call_group(self) -> None:
        """Test case for get_call_group

        Get grouped call metrics
        """
        pass

    def test_get_correlated_traces(self) -> None:
        """Test case for get_correlated_traces

        Resolve Trace IDs from Monitoring Beacons.
        """
        pass

    def test_get_trace_download(self) -> None:
        """Test case for get_trace_download

        Get trace detail
        """
        pass

    def test_get_trace_groups(self) -> None:
        """Test case for get_trace_groups

        Get grouped trace metrics
        """
        pass

    def test_get_traces(self) -> None:
        """Test case for get_traces

        Get all traces
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.apdex_settings_api import ApdexSettingsApi


class TestApdexSettingsApi(unittest.TestCase):
    """ApdexSettingsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApdexSettingsApi()

    def tearDown(self) -> None:
        pass

    def test_create_apdex_configuration(self) -> None:
        """Test case for create_apdex_configuration

        Create Apdex Configuration
        """
        pass

    def test_delete_apdex_configuration(self) -> None:
        """Test case for delete_apdex_configuration

        Delete Apdex Configuration
        """
        pass

    def test_get_all_apdex_configurations(self) -> None:
        """Test case for get_all_apdex_configurations

        Get All Apdex Configurations
        """
        pass

    def test_get_apdex_configuration(self) -> None:
        """Test case for get_apdex_configuration

        Get Apdex Configuration
        """
        pass

    def test_get_apdex_configurations_for_entity_type_and_id(self) -> None:
        """Test case for get_apdex_configurations_for_entity_type_and_id

        Get all Apdex configurations for entity type and entity id
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.o_auth_token import OAuthToken

class TestOAuthToken(unittest.TestCase):
    """OAuthToken unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OAuthToken:
        """Test OAuthToken
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OAuthToken`
        """
        model = OAuthToken()
        if include_optional:
            return OAuthToken(
                access_token = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                expires_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                failed_refresh_attempts = 56,
                last_refresh_attempt = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                milliseconds_until_refresh_needed = 56,
                refresh_token = '',
                scope = '',
                status = 'VALID',
                token_type = '',
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                valid = True
            )
        else:
            return OAuthToken(
        )
        """

    def testOAuthToken(self):
        """Test OAuthToken"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr
from typing import List, Optional
from typing_extensions import Annotated
from instana_client.models.get_payload_keys_result import GetPayloadKeysResult
from instana_client.models.metric_instance import MetricInstance
from instana_client.models.plugin_result import PluginResult
from instana_client.models.search_field_result import SearchFieldResult
from instana_client.models.tag_catalog import TagCatalog

from instana_client.api_client import ApiClient, RequestSerialized
from instana_client.api_response import ApiResponse
from instana_client.rest import RESTResponseType


class InfrastructureCatalogApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_available_payload_keys_by_plugin_id(
        self,
        plugin_id: Annotated[StrictStr, Field(description="plugin id")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[GetPayloadKeysResult]:
        """Get payload keys for plugin

        This endpoint retrieves the list of keys that can be used to retrieve payloads for a plugin. 

        :param plugin_id: plugin id (required)
        :type plugin_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_available_payload_keys_by_plugin_id_serialize(
            plugin_id=plugin_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[GetPayloadKeysResult]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_available_payload_keys_by_plugin_id_with_http_info(
        self,
        plugin_id: Annotated[StrictStr, Field(description="plugin id")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[GetPayloadKeysResult]]:
        """Get payload keys for plugin

        This endpoint retrieves the list of keys that can be used to retrieve payloads for a plugin. 

        :param plugin_id: plugin id (required)
        :type plugin_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_available_payload_keys_by_plugin_id_serialize(
            plugin_id=plugin_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[GetPayloadKeysResult]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_available_payload_keys_by_plugin_id_without_preload_content(
        self,
        plugin_id: Annotated[StrictStr, Field(description="plugin id")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get payload keys for plugin

        This endpoint retrieves the list of keys that can be used to retrieve payloads for a plugin. 

        :param plugin_id: plugin id (required)
        :type plugin_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_available_payload_keys_by_plugin_id_serialize(
            plugin_id=plugin_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[GetPayloadKeysResult]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_available_payload_keys_by_plugin_id_serialize(
        self,
        plugin_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if plugin_id is not None:
            _path_params['pluginId'] = plugin_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/infrastructure-monitoring/catalog/payloads/{pluginId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_infrastructure_catalog_metrics(
        self,
        plugin: StrictStr,
        filter: Optional[StrictStr] = None,
        label: Optional[StrictStr] = None,
        limit: Optional[StrictInt] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[MetricInstance]:
        """Get metric catalog


        :param plugin: (required)
        :type plugin: str
        :param filter:
        :type filter: str
        :param label:
        :type label: str
        :param limit:
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_infrastructure_catalog_metrics_serialize(
            plugin=plugin,
            filter=filter,
            label=label,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[MetricInstance]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_infrastructure_catalog_metrics_with_http_info(
        self,
        plugin: StrictStr,
        filter: Optional[StrictStr] = None,
        label: Optional[StrictStr] = None,
        limit: Optional[StrictInt] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[MetricInstance]]:
        """Get metric catalog


        :param plugin: (required)
        :type plugin: str
        :param filter:
        :type filter: str
        :param label:
        :type label: str
        :param limit:
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_infrastructure_catalog_metrics_serialize(
            plugin=plugin,
            filter=filter,
            label=label,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[MetricInstance]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_infrastructure_catalog_metrics_without_preload_content(
        self,
        plugin: StrictStr,
        filter: Optional[StrictStr] = None,
        label: Optional[StrictStr] = None,
        limit: Optional[StrictInt] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get metric catalog


        :param plugin: (required)
        :type plugin: str
        :param filter:
        :type filter: str
        :param label:
        :type label: str
        :param limit:
        :type limit: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_infrastructure_catalog_metrics_serialize(
            plugin=plugin,
            filter=filter,
            label=label,
            limit=limit,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[MetricInstance]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_infrastructure_catalog_metrics_serialize(
        self,
        plugin,
        filter,
        label,
        limit,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if plugin is not None:
            _path_params['plugin'] = plugin
        # process the query parameters
        if filter is not None:
            
            _query_params.append(('filter', filter))
            
        if label is not None:
            
            _query_params.append(('label', label))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/infrastructure-monitoring/catalog/metrics/{plugin}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_infrastructure_catalog_plugins(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[PluginResult]:
        """Get plugin catalog


        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_infrastructure_catalog_plugins_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[PluginResult]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_infrastructure_catalog_plugins_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[PluginResult]]:
        """Get plugin catalog


        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_infrastructure_catalog_plugins_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[PluginResult]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_infrastructure_catalog_plugins_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get plugin catalog


        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_infrastructure_catalog_plugins_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[PluginResult]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_infrastructure_catalog_plugins_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/infrastructure-monitoring/catalog/plugins',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_infrastructure_catalog_plugins_with_custom_metrics(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[PluginResult]:
        """Get all plugins with custom metrics catalog

        This endpoint retrieves a list of all plugins that have custom metrics

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_infrastructure_catalog_plugins_with_custom_metrics_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[PluginResult]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_infrastructure_catalog_plugins_with_custom_metrics_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[PluginResult]]:
        """Get all plugins with custom metrics catalog

        This endpoint retrieves a list of all plugins that have custom metrics

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_infrastructure_catalog_plugins_with_custom_metrics_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[PluginResult]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_infrastructure_catalog_plugins_with_custom_metrics_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get all plugins with custom metrics catalog

        This endpoint retrieves a list of all plugins that have custom metrics

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_infrastructure_catalog_plugins_with_custom_metrics_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[PluginResult]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_infrastructure_catalog_plugins_with_custom_metrics_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/infrastructure-monitoring/catalog/plugins-with-custom-metrics',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_infrastructure_catalog_search_fields(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[SearchFieldResult]:
        """get search field catalog


        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_infrastructure_catalog_search_fields_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[SearchFieldResult]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_infrastructure_catalog_search_fields_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[SearchFieldResult]]:
        """get search field catalog


        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_infrastructure_catalog_search_fields_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[SearchFieldResult]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_infrastructure_catalog_search_fields_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get search field catalog


        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_infrastructure_catalog_search_fields_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[SearchFieldResult]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_infrastructure_catalog_search_fields_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/infrastructure-monitoring/catalog/search',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_tag_catalog(
        self,
        plugin: Annotated[StrictStr, Field(description="plugin")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> TagCatalog:
        """Get available tags for a particular plugin

        This endpoint retrieves the tag catalog filtered by plugin.

        :param plugin: plugin (required)
        :type plugin: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_tag_catalog_serialize(
            plugin=plugin,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TagCatalog",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_tag_catalog_with_http_info(
        self,
        plugin: Annotated[StrictStr, Field(description="plugin")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[TagCatalog]:
        """Get available tags for a particular plugin

        This endpoint retrieves the tag catalog filtered by plugin.

        :param plugin: plugin (required)
        :type plugin: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_tag_catalog_serialize(
            plugin=plugin,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TagCatalog",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_tag_catalog_without_preload_content(
        self,
        plugin: Annotated[StrictStr, Field(description="plugin")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get available tags for a particular plugin

        This endpoint retrieves the tag catalog filtered by plugin.

        :param plugin: plugin (required)
        :type plugin: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_tag_catalog_serialize(
            plugin=plugin,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TagCatalog",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_tag_catalog_serialize(
        self,
        plugin,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if plugin is not None:
            _path_params['plugin'] = plugin
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/infrastructure-monitoring/catalog/tags/{plugin}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_tag_catalog_all(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> TagCatalog:
        """Get available tags

        This endpoint retrieves the tag catalog.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_tag_catalog_all_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TagCatalog",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_tag_catalog_all_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[TagCatalog]:
        """Get available tags

        This endpoint retrieves the tag catalog.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_tag_catalog_all_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TagCatalog",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_tag_catalog_all_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get available tags

        This endpoint retrieves the tag catalog.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_tag_catalog_all_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TagCatalog",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_tag_catalog_all_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/infrastructure-monitoring/catalog/tags',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )


